@@ -69,13 +69,14 @@ class Domoticz(IPlugin):
 		if jsonInput['outcome']['entities']['location']['body'] :
 			location = jsonInput['outcome']['entities']['location']['body']
 		else:
-			bodies = "pas de lieu"
+			location = "pas de lieu"
+			bodies = ""
 
 		if jsonInput['outcome']['entities']['local_search_query']['value'] :
 			local = jsonInput['outcome']['entities']['local_search_query']['value']
 		else:
 			local = "pas de local_search_query"
-			bodies = " pas de parametres secondaires"
+			bodies = ""
 #
 		idex= local + " " + location +  "_"
 		log.msg("index :  %s" % (idex))		
